@@ -1,7 +1,7 @@
 package Task::BeLike::SARTAK;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 
@@ -17,11 +17,11 @@ See the F<Makefile.PL> in this distribution.
 
 =head1 AUTHOR
 
-Shawn M Moore C<sartak@gmail.com>
+Shawn M Moore C<code@sartak.org>
 
 =head1 COPYRIGHT
 
-Copyright 2011 Shawn M Moore.
+Copyright 2011-2012 Shawn M Moore.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
